All encoding and decoding is done via u64. So all types must implement this trait to be able to be encoded and decoded.
Traits
- BitCast
- All encoding and decoding is done via u64. So all types must implement this trait to be able to be encoded and decoded.